"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const react_native_1 = require("react-native");
const core_1 = require("@replyke/core");
const ui_core_react_native_1 = require("@replyke/ui-core-react-native");
const comments_social_core_1 = require("@replyke/comments-social-core");
const ReplyBanner_1 = __importDefault(require("./ReplyBanner"));
const MentionSuggestions_1 = __importDefault(require("./MentionSuggestions"));
const NewCommentForm = (0, react_1.forwardRef)(({ withEmojis = true }, ref) => {
    const { user } = (0, core_1.useUser)();
    const { project } = (0, core_1.useProject)();
    const giphyApiKey = project?.integrations.find((int) => int.name === "giphy")
        ?.data.apiKey;
    const { pushMention, createComment, submittingComment, callbacks } = (0, core_1.useCommentSection)();
    const { styleConfig } = (0, comments_social_core_1.useSocialStyleConfig)();
    const [isGiphyVisible, setIsGiphyVisible] = (0, react_1.useState)(false);
    const { backgroundColor, withAvatar, itemsGap, verticalPadding, paddingLeft, paddingRight, authorAvatarSize, placeholderText, textareaTextSize, postButtonText, postButtonFontSize, postButtonFontColor, postButtonFontWeight, } = styleConfig.newCommentFormProps;
    const textAreaRef = (0, react_1.useRef)(null);
    const [content, setContent] = (0, react_1.useState)("");
    const { cursorPosition, isSelectionActive, handleSelectionChange, handleTextChange, } = (0, ui_core_react_native_1.useTextInputCursorIndicator)();
    const { isMentionActive, loading, mentionSuggestions, handleMentionClick, mentions, addMention, resetMentions, } = (0, core_1.useMentions)({
        content,
        setContent,
        focus: () => textAreaRef.current?.focus(),
        cursorPosition,
        isSelectionActive,
    });
    const handleCreateComment = (0, react_1.useCallback)(async () => {
        if (!user) {
            callbacks?.loginRequiredCallback?.();
            return;
        }
        const tempContent = content;
        try {
            setContent("");
            react_native_1.Keyboard.dismiss(); // Dismiss the keyboard
            await createComment({ content, mentions });
            resetMentions();
        }
        catch (err) {
            setContent(tempContent);
            (0, core_1.handleError)(err, "Creating comment failed: ");
        }
    }, [createComment, mentions, resetMentions, callbacks, user]);
    const handleCreateGif = (0, react_1.useCallback)(async (gif) => {
        if (!user) {
            callbacks?.loginRequiredCallback?.();
            return;
        }
        setContent("");
        resetMentions();
        setIsGiphyVisible(false);
        try {
            await createComment({ gif, mentions });
        }
        catch (err) {
            (0, core_1.handleError)(err, "Creating comment failed: ");
        }
    }, [createComment, mentions, resetMentions, callbacks, user]);
    (0, react_1.useEffect)(() => {
        if (!pushMention)
            return;
        const textArea = textAreaRef.current;
        if (!textArea)
            throw new Error("Can't find textarea");
        // if (pushMention.id === previousPushMention?.id) return;
        if (!pushMention.username) {
            (callbacks?.userCantBeMentionedCallback ??
                (() => react_native_1.Alert.alert("User has no username")))();
            return;
        }
        addMention(pushMention);
        setContent((prevContent) => `@${pushMention.username} ${prevContent}`);
    }, [pushMention]);
    const handleKeyPress = (0, react_1.useCallback)((event) => {
        if (event.nativeEvent.key === "Enter") {
            handleCreateComment();
        }
        // If you want Shift+Enter or Ctrl+Enter to create a new line, you can leave this as-is.
    }, [handleCreateComment]);
    const adjustTextareaHeight = () => {
        const textArea = textAreaRef.current;
        if (textArea) {
            textArea.measure((fx, fy, width, height, px, py) => {
                const baseHeight = 20; // Example base height in pixels. Adjust this value to match your design.
                const newHeight = Math.max(baseHeight, Math.min(100, height));
                textArea.setNativeProps({
                    style: { height: newHeight },
                });
            });
        }
    };
    // useEffect(() => {
    //   adjustTextareaHeight();
    // }, [body]);
    (0, react_1.useLayoutEffect)(() => {
        const timeout = setTimeout(() => adjustTextareaHeight(), 500);
        return () => clearTimeout(timeout);
    }, []);
    // Expose the focus method to the parent through the forwarded ref
    (0, react_1.useImperativeHandle)(ref, () => ({
        focus: () => {
            textAreaRef.current?.focus();
        },
    }));
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [giphyApiKey ? ((0, jsx_runtime_1.jsx)(ui_core_react_native_1.GiphyContainer, { giphyApiKey: giphyApiKey, onClickBack: () => setIsGiphyVisible(false), onSelectGif: (selected) => handleCreateGif(selected), visible: isGiphyVisible })) : null, (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: {
                    ...ui_core_react_native_1.resetView,
                    position: "relative",
                    overflow: "visible",
                    backgroundColor,
                }, children: [(0, jsx_runtime_1.jsxs)(react_native_1.View, { style: { width: "100%", position: "relative", overflow: "visible" }, children: [(0, jsx_runtime_1.jsx)(ReplyBanner_1.default, {}), (0, jsx_runtime_1.jsx)(MentionSuggestions_1.default, { isMentionActive: isMentionActive, isLoadingMentions: loading, mentionSuggestions: mentionSuggestions, handleMentionClick: handleMentionClick })] }), (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: {
                            ...ui_core_react_native_1.resetView,
                            position: "relative",
                            zIndex: 20,
                            backgroundColor,
                        }, children: [withEmojis && ((0, jsx_runtime_1.jsx)(ui_core_react_native_1.EmojiSuggestions, { onEmojiClick: (emoji) => {
                                    setContent((c) => c + emoji);
                                } })), (0, jsx_runtime_1.jsxs)(react_native_1.View, { style: {
                                    flexDirection: "row",
                                    alignItems: "center",
                                    justifyContent: "flex-end",
                                    gap: itemsGap,
                                    paddingTop: verticalPadding,
                                    paddingBottom: verticalPadding,
                                    paddingLeft,
                                    paddingRight,
                                    borderTopColor: "#e7e7e7",
                                    borderTopWidth: 1,
                                }, children: [user && withAvatar && ((0, jsx_runtime_1.jsx)(ui_core_react_native_1.UserAvatar, { user: user, size: authorAvatarSize, borderRadius: authorAvatarSize })), (0, jsx_runtime_1.jsx)(react_native_1.TextInput, { ref: textAreaRef, numberOfLines: 1, placeholder: placeholderText, value: content, onChangeText: (text) => {
                                            setContent(text);
                                            handleTextChange(text);
                                        }, onSelectionChange: handleSelectionChange, onKeyPress: handleKeyPress, onSubmitEditing: () => handleCreateComment(), blurOnSubmit: false, style: {
                                            ...ui_core_react_native_1.resetTextInput,
                                            flex: 1,
                                            marginHorizontal: 8,
                                            fontSize: textareaTextSize,
                                        } }), content.length === 0 && giphyApiKey ? ((0, jsx_runtime_1.jsx)(react_native_1.TouchableOpacity, { onPress: () => setIsGiphyVisible(true), disabled: submittingComment, style: { ...ui_core_react_native_1.resetButton }, children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: {
                                                fontWeight: postButtonFontWeight,
                                                fontSize: postButtonFontSize,
                                                color: postButtonFontColor,
                                            }, children: "GIF" }) })) : ((0, jsx_runtime_1.jsx)(react_native_1.TouchableOpacity, { onPress: handleCreateComment, disabled: submittingComment, style: { ...ui_core_react_native_1.resetButton }, children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: {
                                                fontWeight: postButtonFontWeight,
                                                fontSize: postButtonFontSize,
                                                color: postButtonFontColor,
                                            }, children: postButtonText }) }))] })] })] })] }));
});
exports.default = NewCommentForm;
//# sourceMappingURL=NewCommentForm.js.map