"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const comments_social_core_1 = require("@replyke/comments-social-core");
const core_1 = require("@replyke/core");
const useSocialComments_1 = __importDefault(require("../hooks/useSocialComments"));
const react_native_1 = require("react-native");
function SocialCommentSection({ callbacks, styleConfig: styleConfigProp, isVisible = true, sortOptions = ["top", "new", "old"], header, }) {
    const { entity } = (0, core_1.useEntity)();
    const styleConfig = (0, comments_social_core_1.useSocialStyle)(styleConfigProp);
    const { CommentSectionProvider, SortByButton, CommentsFeed, NewCommentForm } = (0, useSocialComments_1.default)({
        entityId: entity?.id,
        styleConfig,
        callbacks,
    });
    const buttonStyles = {
        active: {
            backgroundColor: "black",
            paddingVertical: 4,
            paddingHorizontal: 8,
            borderRadius: 6,
        },
        inactive: {
            backgroundColor: "#e5e7eb",
            paddingVertical: 4,
            paddingHorizontal: 8,
            borderRadius: 6,
        },
        textActive: {
            color: "white",
            fontSize: 12,
        },
        textInactive: {
            color: "black",
            fontSize: 12,
        },
    };
    const renderSortButtons = () => {
        if (!sortOptions)
            return null;
        const optionsMap = {
            top: { label: "Top", priority: "top" },
            new: { label: "New", priority: "new" },
            old: { label: "Old", priority: "old" },
        };
        return sortOptions.map((option, index) => {
            const { label, priority } = optionsMap[option];
            const isFirst = index === 0;
            const marginStyle = isFirst ? {} : { marginLeft: 4 };
            return ((0, jsx_runtime_1.jsx)(SortByButton, { priority: priority, activeView: (0, jsx_runtime_1.jsx)(react_native_1.TouchableOpacity, { style: [buttonStyles.active, marginStyle], children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: buttonStyles.textActive, children: label }) }), nonActiveView: (0, jsx_runtime_1.jsx)(react_native_1.TouchableOpacity, { style: [buttonStyles.inactive, marginStyle], children: (0, jsx_runtime_1.jsx)(react_native_1.Text, { style: buttonStyles.textInactive, children: label }) }) }, priority));
        });
    };
    return ((0, jsx_runtime_1.jsxs)(CommentSectionProvider, { children: [(header || sortOptions) && ((0, jsx_runtime_1.jsxs)(react_native_1.View, { style: {
                    flexDirection: "row",
                    paddingLeft: 24,
                    paddingRight: 24,
                    alignItems: "center",
                }, children: [(0, jsx_runtime_1.jsx)(react_native_1.View, { style: { flex: 1 }, children: header }), sortOptions !== null && renderSortButtons()] })), (0, jsx_runtime_1.jsx)(react_native_1.ScrollView, { style: { flex: 1, backgroundColor: "#ffffff" }, children: (0, jsx_runtime_1.jsx)(CommentsFeed, {}) }), (0, jsx_runtime_1.jsx)(react_native_1.View, { style: {
                    borderTopWidth: 1,
                    borderTopColor: "#e5e7eb",
                }, children: isVisible && (0, jsx_runtime_1.jsx)(NewCommentForm, {}) })] }));
}
exports.default = SocialCommentSection;
//# sourceMappingURL=SocialCommentSection.js.map