import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useSocialStyle, } from "@replyke/comments-social-core";
import { useEntity } from "@replyke/core";
import useSocialComments from "../hooks/useSocialComments";
import { ScrollView, Text, TouchableOpacity, View } from "react-native";
function SocialCommentSection({ callbacks, styleConfig: styleConfigProp, isVisible = true, sortOptions = ["top", "new", "old"], header, }) {
    const { entity } = useEntity();
    const styleConfig = useSocialStyle(styleConfigProp);
    const { CommentSectionProvider, SortByButton, CommentsFeed, NewCommentForm } = useSocialComments({
        entityId: entity?.id,
        styleConfig,
        callbacks,
    });
    const buttonStyles = {
        active: {
            backgroundColor: "black",
            paddingVertical: 4,
            paddingHorizontal: 8,
            borderRadius: 6,
        },
        inactive: {
            backgroundColor: "#e5e7eb",
            paddingVertical: 4,
            paddingHorizontal: 8,
            borderRadius: 6,
        },
        textActive: {
            color: "white",
            fontSize: 12,
        },
        textInactive: {
            color: "black",
            fontSize: 12,
        },
    };
    const renderSortButtons = () => {
        if (!sortOptions)
            return null;
        const optionsMap = {
            top: { label: "Top", priority: "top" },
            new: { label: "New", priority: "new" },
            old: { label: "Old", priority: "old" },
        };
        return sortOptions.map((option, index) => {
            const { label, priority } = optionsMap[option];
            const isFirst = index === 0;
            const marginStyle = isFirst ? {} : { marginLeft: 4 };
            return (_jsx(SortByButton, { priority: priority, activeView: _jsx(TouchableOpacity, { style: [buttonStyles.active, marginStyle], children: _jsx(Text, { style: buttonStyles.textActive, children: label }) }), nonActiveView: _jsx(TouchableOpacity, { style: [buttonStyles.inactive, marginStyle], children: _jsx(Text, { style: buttonStyles.textInactive, children: label }) }) }, priority));
        });
    };
    return (_jsxs(CommentSectionProvider, { children: [(header || sortOptions) && (_jsxs(View, { style: {
                    flexDirection: "row",
                    paddingLeft: 24,
                    paddingRight: 24,
                    alignItems: "center",
                }, children: [_jsx(View, { style: { flex: 1 }, children: header }), sortOptions !== null && renderSortButtons()] })), _jsx(ScrollView, { style: { flex: 1, backgroundColor: "#ffffff" }, children: _jsx(CommentsFeed, {}) }), _jsx(View, { style: {
                    borderTopWidth: 1,
                    borderTopColor: "#e5e7eb",
                }, children: isVisible && _jsx(NewCommentForm, {}) })] }));
}
export default SocialCommentSection;
//# sourceMappingURL=SocialCommentSection.js.map